given a bar-delimited string as produced for dbXrefs in gene_info, extract the value associated with a given tag
Source:R/NGparq.R
processDbx.Rdgiven a bar-delimited string as produced for dbXrefs in gene_info, extract the value associated with a given tag