given an element of a bar-delimited string as produced for dbXrefs in gene_info, extract the value associated with a given tag
Source:R/NGparq.R
processDbx1.Rdgiven an element of a bar-delimited string as produced for dbXrefs in gene_info, extract the value associated with a given tag